@@ -16,7 +16,7 @@ import logging
 
 import botocore.session
 from botocore import __version__ as botocore_version
-from botocore.hooks import AliasedEventEmitter
+from botocore.hooks import HierarchicalEmitter
 from botocore import xform_name
 from botocore.compat import copy_kwargs, OrderedDict
 from botocore.exceptions import NoCredentialsError
@@ -62,11 +62,10 @@ def main():
 
 
 def create_clidriver():
-    emitter = AliasedEventEmitter()
-    session = botocore.session.Session(EnvironmentVariables, emitter)
+    session = botocore.session.Session(EnvironmentVariables)
     _set_user_agent_for_session(session)
     load_plugins(session.full_config.get('plugins', {}),
-                 event_hooks=emitter)
+                 event_hooks=session.get_component('event_emitter'))
     driver = CLIDriver(session=session)
     return driver
 
